@@ -41,6 +41,9 @@ try:
     import features.mic_input_ai.mic_input_ai.SpeechRecognition as SpeechRecognitionAI
     import features.jarvisai_api.jarvisai_api.JarvisAIAPI
     import features.detection.detection.Detections
+    import features.chatbot.chatbot.start_chatbot_large as chatbot_lrg
+    import features.chatbot.chatbot.start_chatbot_small as chatbot_sml
+    import features.chatbot.chatbot.load_chatbot_models as load_ch_model
 except Exception as e:
     from JarvisAI.features.weather import weather as wea
     from JarvisAI.features.website_open import website_open
@@ -61,20 +64,31 @@ except Exception as e:
     from JarvisAI.features.mic_input_ai.mic_input_ai import SpeechRecognition as SpeechRecognitionAI
     from JarvisAI.features.jarvisai_api.jarvisai_api import JarvisAIAPI
     from JarvisAI.features.detection.detection import Detections
+    from JarvisAI.features.chatbot.chatbot import start_chatbot_large as chatbot_lrg
+    from JarvisAI.features.chatbot.chatbot import start_chatbot_small as chatbot_sml
+    from JarvisAI.features.chatbot.chatbot import load_chatbot_models as load_ch_model
 
 
 class JarvisAssistant:
-    def __init__(self, sync=True, token=None):
+    def __init__(self, sync=True, token=None, disable_msg=False, load_chatbot_model=True, high_accuracy_chatbot_model=False,
+                 chatbot_large=False):
+        if load_chatbot_model:
+            self.chatbot_model = load_ch_model(high_accuracy_chatbot_model, chatbot_large)
+        self.load_chatbot_model = load_chatbot_model
         if token is None or not sync:
-            print("\n")
-            cprint("Set 'obj = JarvisAI.JarvisAssistant(sync=False, token='xyz')' if you do not want to use API",
-                   color='green')
-            cprint("Obtain your token from: http://jarvis-ai-api.herokuapp.com/", color='green')
-            cprint("Its free to use. Even API services is also free. \n"
-                   "Well, JarvisAI need support of your to keep this project and it's API alive.\n"
-                   "So, your contribution/donation will be appreciated. \n"
-                   , color='blue')
-            cprint("DONATE: https://www.buymeacoffee.com/dipeshpal", color='red')
+            if not disable_msg:
+                print("\n")
+                cprint("Set 'obj = JarvisAI.JarvisAssistant(sync=False)' if you do not want to use API",
+                       color='green')
+                cprint("Obtain your token from: http://jarvis-ai-api.herokuapp.com/", color='green')
+                cprint("Its free to use. Even API services is also free. \n"
+                       "Well, JarvisAI need support of your to keep this project and it's API alive.\n"
+                       "So, your contribution/donation will be appreciated. \n"
+                       , color='blue')
+                cprint("DONATE: https://www.buymeacoffee.com/dipeshpal", color='red')
+                cprint("Set 'obj = JarvisAI.JarvisAssistant(disable_msg=True)' if you do not want to display this message",
+                       color='green')
+                cprint("Initializing JarvisAI...", color='yellow')
         self.sync = sync
         self.token = token
         self.speech_recognition_ai = SpeechRecognitionAI()
@@ -444,22 +458,61 @@ class JarvisAssistant:
         fingers, hand_type, cv2, img, cap = self.obj_detection.detect_hands(message)
         return fingers, hand_type, cv2, img, cap
 
+    # def load_chatbot_model(self, high_accuracy=False, chatbot_large=False):
+    #     """
+    #     @param high_accuracy: bool (example: False)
+    #     @param chatbot_large: bool (example: False)
+    #     if you are using chatbot_large then set 'chatbot_large=True', It will required more memory
+    #     @return:
+    #         fingers: list (Number of fingers up),
+    #     """
+    #     chatbot_model = load_ch_model(high_accuracy, chatbot_large)
+    #     return chatbot_model
 
-if __name__ == '__main__':
-    obj = JarvisAssistant()
-    # obj.jarvisai_detect_hands()
-    # print(obj.mic_input_ai())
-    # print(obj.text2speech_male())
-    # res = obj.tell_me_joke()
-    # print(res)
-    # obj.text2speech("hello")
-    # res = obj.website_opener("facebook.com")
-    # res = obj.send_mail()
-    # res = obj.launch_app("edge")
-    # res = obj.weather("mumbai")
-    # res = obj.news()
-    # res = obj.tell_me()
-    # res = obj.tell_me_time()
-    # res = obj.tell_me_date()
-    # res = obj.shutdown()
-    # obj.datasetcreate()
+    def chatbot_base(self, input_text):
+        """
+        Conversational Chatbot without using wikipedia/google search
+        Note:
+            1. Use 'chatbot_base' if you have low memory (low accuracy) otherwise use 'chatbot_large' (high accuracy)
+            2. Set 'JarvisAI.JarvisAssistant(high_accuracy_chatbot_model=False)' for low memory system (It gives low accuracy)
+        @param input_text: str (example: Hello!)
+        @return: str
+        """
+        if not self.load_chatbot_model:
+            print("You need to Set 'JarvisAI.JarvisAssistant(load_chatbot_model=True)' first")
+            print("Exiting now, try again...")
+        return chatbot_sml(input_text, self.chatbot_model)
+
+    def chatbot_large(self, input_text):
+        """
+        If chat bot can't answer then it will do wikipedia/google search
+        Note:
+           1. Use 'chatbot_large' if you have high memory
+           2. Set 'JarvisAI.JarvisAssistant(high_accuracy_chatbot_model=True)' for high memory system (It gives high accuracy)
+        @param input_text: str (example: Hello!)
+        @return: str
+        """
+        if not self.load_chatbot_model:
+            print("You need to Set 'JarvisAI.JarvisAssistant(load_chatbot_model=True)' first")
+            print("Exiting now, try again...")
+        return chatbot_lrg(input_text, self.chatbot_model)
+
+    if __name__ == '__main__':
+        pass
+        # obj = JarvisAssistant()
+        # obj.jarvisai_detect_hands()
+        # print(obj.mic_input_ai())
+        # print(obj.text2speech_male())
+        # res = obj.tell_me_joke()
+        # print(res)
+        # obj.text2speech("hello")
+        # res = obj.website_opener("facebook.com")
+        # res = obj.send_mail()
+        # res = obj.launch_app("edge")
+        # res = obj.weather("mumbai")
+        # res = obj.news()
+        # res = obj.tell_me()
+        # res = obj.tell_me_time()
+        # res = obj.tell_me_date()
+        # res = obj.shutdown()
+        # obj.datasetcreate()
